@@ -13,7 +13,9 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 9 Temple Place - Suite 330, Boston, MA 02111-1307,
+   USA.
+*/
 
 #include "defs.h"
 
@@ -62,6 +64,7 @@ get_new_pred (void)
   last_pred->p_type = NO_TYPE;
   last_pred->p_prec = NO_PREC;
   last_pred->side_effects = false;
+  last_pred->no_default_print = false;
   last_pred->need_stat = true;
   last_pred->args.str = NULL;
   last_pred->pred_next = NULL;
